import {
  toValidFilename
} from "./chunk-TYWNSO7K.js";
import {
  cloneObject
} from "./chunk-5BQNKE5C.js";
import {
  jsonStringifySafe
} from "./chunk-VWBTJP5F.js";

// src/node/filestorage.ts
import { mkdirSync, readFileSync, readdirSync, rmSync, unlinkSync, writeFileSync } from "node:fs";
import { dirname, resolve } from "node:path";
import { Buffer } from "node:buffer";
import process from "node:process";
var FileStorage = class {
  constructor(opt = {}) {
    this.store = {};
    this.fileKeys = void 0;
    this.pretty = false;
    this.dirname = resolve(process.cwd(), opt.path ?? ".fileStorage");
    this.pretty = !!opt.pretty;
    this.extension = opt.extension ?? ".json";
    if (opt.extension && !this.extension.startsWith("."))
      this.extension = `.${this.extension}`;
    this.extensionLength = this.extension.length;
    this.objectToString = opt.objectToString ?? ((data) => {
      return this.pretty ? jsonStringifySafe(data, null, 2) : jsonStringifySafe(data);
    });
    this.objectFromString = opt.objectFromString ?? ((data) => {
      try {
        return JSON.parse(data);
      } catch (err) {
      }
    });
    this.keyToFilename = opt.keyToFilename ?? toValidFilename;
  }
  setItem(key, value) {
    this.store[key] = cloneObject(value);
    try {
      const data = this.objectToString(value);
      const path = this.getPath(key);
      mkdirSync(dirname(path), { recursive: true });
      writeFileSync(path, data, "utf8");
    } catch (err) {
    }
  }
  getPath(key) {
    return resolve(this.dirname, this.keyToFilename(key) + this.extension);
  }
  getBuffer(key) {
    const path = this.getPath(key);
    return Buffer.from(readFileSync(path));
  }
  getItem(key) {
    const value = this.store[key];
    if (value === null)
      return;
    if (value != null)
      return cloneObject(value);
    try {
      const path = this.getPath(key);
      const data = readFileSync(path, "utf8");
      if (data != null) {
        const value2 = this.objectFromString(data);
        this.store[key] = value2;
        return value2;
      }
    } catch (err) {
      this.store[key] = null;
    }
  }
  removeItem(key) {
    delete this.store[key];
    if (this.fileKeys != null) {
      const index = this.fileKeys.indexOf(key);
      if (index !== -1)
        this.fileKeys.splice(index, 1);
    }
    try {
      const path = this.getPath(key);
      unlinkSync(path);
    } catch (err) {
    }
  }
  clear() {
    this.fileKeys = [];
    this.store = {};
    rmSync(this.dirname, { recursive: true, force: true });
  }
  allKeys() {
    if (this.fileKeys == null) {
      try {
        this.fileKeys = readdirSync(this.dirname, { withFileTypes: true }).filter(
          (item) => !item.isDirectory() && item.name.endsWith(this.extension)
        ).map((item) => item.name.slice(0, -this.extensionLength)) || [];
      } catch (err) {
      }
    }
    const keys = [...this.fileKeys || []];
    for (const key of Object.keys(this.store)) {
      if (!keys.includes(key))
        keys.push(key);
    }
    keys.sort();
    return keys;
  }
};

export {
  FileStorage
};
//# sourceMappingURL=chunk-2ZD5GKMZ.js.map