import {
  isArray,
  isObject,
  isPrimitive,
  isRecord
} from "./chunk-AY5LGXTC.js";

// src/common/data/deep.ts
function deepEqual(a, b, hash = /* @__PURE__ */ new WeakSet()) {
  if (a === b)
    return true;
  if (hash.has(b)) {
    return false;
  }
  if (!isPrimitive(b))
    hash.add(b);
  if (!(a instanceof Object) || !(b instanceof Object))
    return false;
  if (a.constructor !== b.constructor)
    return false;
  if (a.length !== b.length)
    return false;
  for (const p in a) {
    if (!a.hasOwnProperty(p))
      continue;
    if (!b.hasOwnProperty(p))
      return false;
    const aa = a[p];
    const bb = b[p];
    if (!deepEqual(aa, bb, hash))
      return false;
  }
  for (const p in b) {
    if (b.hasOwnProperty(p) && !a.hasOwnProperty(p))
      return false;
  }
  return true;
}
function deepStripUndefinedInPlace(a, hash = /* @__PURE__ */ new WeakSet()) {
  if (hash.has(a))
    return "[Circular ~]";
  if (!isPrimitive(a))
    hash.add(a);
  if (isRecord(a)) {
    for (const p in a) {
      if (!a.hasOwnProperty(p))
        continue;
      if (a[p] === void 0) {
        delete a[p];
        continue;
      }
      deepStripUndefinedInPlace(a[p], hash);
    }
  } else if (isArray(a)) {
    for (let i = a.length - 1; i >= 0; i--) {
      if (a[i] === void 0)
        a.splice(i, 1);
    }
  }
  return a;
}
function deepMerge(target, ...sources) {
  for (const source of sources) {
    if (!isObject(target))
      target = {};
    if (source == null || !isObject(source))
      continue;
    Object.keys(source).forEach((key) => {
      const targetValue = target[key];
      const sourceValue = source[key];
      if (Array.isArray(targetValue) && Array.isArray(sourceValue))
        target[key] = targetValue.concat(sourceValue);
      else if (isObject(targetValue) && isObject(sourceValue))
        target[key] = deepMerge(Object.assign({}, targetValue), sourceValue);
      else
        target[key] = sourceValue;
    });
  }
  return target;
}

export {
  deepEqual,
  deepStripUndefinedInPlace,
  deepMerge
};
//# sourceMappingURL=chunk-DXSTF7NX.js.map