import {
  deepEqual
} from "./chunk-DXSTF7NX.js";
import {
  isRecord
} from "./chunk-AY5LGXTC.js";
import {
  arrayMinus
} from "./chunk-DUON5DN5.js";
import {
  cloneObject
} from "./chunk-5BQNKE5C.js";

// src/common/data/object-changes.ts
function objectAssignDeepInPlace(toObject, fromObject) {
  if (isRecord(toObject) && isRecord(fromObject)) {
    const fromKeys = Object.keys(fromObject);
    for (const key of arrayMinus(Object.keys(toObject), fromKeys))
      delete toObject[key];
    for (const key of fromKeys) {
      const from = fromObject[key];
      const to = toObject[key];
      if (isRecord(from)) {
        if (isRecord(to))
          objectAssignDeepInPlace(to, from);
        else
          toObject[key] = cloneObject(from);
      } else if (from !== to) {
        toObject[key] = from;
      }
    }
  }
  return toObject;
}
function objectDescribeChange(fromObject, toObject) {
  const change = {};
  for (const key of arrayMinus(Object.keys(fromObject), Object.keys(toObject)))
    change[key] = null;
  for (const [key, value] of Object.entries(toObject)) {
    const from = fromObject[key];
    if (isRecord(value)) {
      const subChange = objectDescribeChange(from ?? {}, value);
      if (subChange != null)
        change[key] = subChange;
    } else if (!(value == null && from == null)) {
      if (!deepEqual(value, from))
        change[key] = value == null ? null : value;
    }
  }
  return Object.keys(change).length > 0 ? change : void 0;
}

export {
  objectAssignDeepInPlace,
  objectDescribeChange
};
//# sourceMappingURL=chunk-KCHV27UP.js.map