"use strict";Object.defineProperty(exports, "__esModule", {value: true}); function _nullishCoalesce(lhs, rhsFn) { if (lhs != null) { return lhs; } else { return rhsFn(); } } function _optionalChain(ops) { let lastAccessLHS = undefined; let value = ops[0]; let i = 1; while (i < ops.length) { const op = ops[i]; const fn = ops[i + 1]; i += 2; if ((op === 'optionalAccess' || op === 'optionalCall') && value == null) { return undefined; } if (op === 'access' || op === 'optionalAccess') { lastAccessLHS = value; value = fn(value); } else if (op === 'call' || op === 'optionalCall') { value = fn((...args) => value.call(lastAccessLHS, ...args)); lastAccessLHS = undefined; } } return value; }

var _chunkZOA7N26Rcjs = require('./chunk-ZOA7N26R.cjs');


var _chunkBNY33VPPcjs = require('./chunk-BNY33VPP.cjs');


var _chunkXYGMYIEVcjs = require('./chunk-XYGMYIEV.cjs');


var _chunkJ42M6DF3cjs = require('./chunk-J42M6DF3.cjs');

// src/common/exec/queue.ts
var SerialQueue = class extends _chunkZOA7N26Rcjs.Emitter {
  constructor(opt = {}) {
    super();
    this.queue = [];
    this.waitToFinish = [];
    this.countMax = 0;
    this.countResolved = 0;
    this.paused = false;
    const { name = _chunkBNY33VPPcjs.uname.call(void 0, "queue"), logLevel } = opt;
    this.name = name;
    this.log = _chunkXYGMYIEVcjs.DefaultLogger.call(void 0, `zeed:queue:${name}`, _nullishCoalesce(logLevel, () => ( _chunkJ42M6DF3cjs.LogLevelOff)));
  }
  async performNext() {
    this.log("performNext, queue.length =", this.queue.length);
    if (this.currentTask != null) {
      this.log("performNext => skip while another task is running");
      return;
    }
    if (this.paused) {
      this.log("performNext => skip while is paused");
      return;
    }
    while (this.currentTask == null && !this.paused) {
      const info = this.queue.shift();
      this.log(`performNext => ${_optionalChain([info, 'optionalAccess', _ => _.name])}`);
      if (info == null)
        break;
      if (this.countResolved === 0)
        void this.emit("didStart", this.countMax);
      const { name, task, resolve } = info;
      this.currentTask = task();
      let result;
      try {
        this.log.info(`start task ${name}`);
        result = await this.currentTask;
        this.log(`finished task ${name} with result =`, result);
      } catch (err) {
        this.log.warn("Error performing task", err);
      }
      resolve(result);
      this.currentTask = void 0;
      this.countResolved += 1;
      void this.emit("didUpdate", this.countMax, this.countResolved);
    }
    if (this.queue.length === 0) {
      void this.emit("didFinish");
      this.countMax = 0;
      this.countResolved = 0;
    }
    while (this.waitToFinish.length > 0)
      this.waitToFinish.shift()();
  }
  /** Enqueue task to be executed when all other tasks are done. Except `immediate = true`. */
  async enqueue(task, opt = {}) {
    const { immediate = false, name = _chunkBNY33VPPcjs.uname.call(void 0, this.name) } = opt;
    if (immediate) {
      this.log.info(`immediate execution ${name}`);
      return await task();
    }
    this.log(`enqueue ${name}`);
    return new Promise((resolve) => {
      this.queue.push({
        name,
        task,
        resolve
      });
      this.countMax += 1;
      void this.emit("didUpdate", this.countMax, this.countResolved);
      void this.performNext();
    });
  }
  /** If a task is already performing, execute immediately. Otherwise enqueue as usual. */
  async enqueueReentrant(task, opt = {}) {
    return this.enqueue(task, {
      immediate: this.currentTask != null,
      name: opt.name
    });
  }
  /** Remove all tasks from queue that are not yet executing. */
  async cancelAll(_unblock = true) {
    this.log("cancelAll");
    void this.emit("didCancel");
    const resolver = this.queue.map((task) => task.resolve);
    this.queue = [];
    resolver.forEach((r) => r(void 0));
    await this.wait();
  }
  /** Pause execution after current task is finished. */
  async pause() {
    this.log("pause");
    this.paused = true;
    await this.wait();
  }
  /** Resume paused queue. */
  resume() {
    this.log("resume");
    this.paused = false;
    void this.performNext();
  }
  /** Wait for all tasks to finish */
  async wait() {
    this.log("wait");
    if (this.currentTask == null && (this.queue.length === 0 || this.paused))
      return;
    return new Promise((resolve) => {
      this.waitToFinish.push(resolve);
    });
  }
  get isPaused() {
    return this.paused;
  }
  get hasTasks() {
    return this.queue.length !== 0;
  }
};



exports.SerialQueue = SerialQueue;
//# sourceMappingURL=chunk-LARONVYA.cjs.map