import {
  getSecureRandomIfPossible
} from "./chunk-IZT6OHMS.js";

// src/common/data/sorted.ts
function useSorted(config = {}) {
  const {
    getter = (item) => item.sort
    // setter = (item: any, value) => (item.sort = value),
  } = config;
  function items(items2) {
    items2.sort((a, b) => (getter(a) || 0) - (getter(b) || 0));
    return items2;
  }
  function start(items2) {
    return items2.reduce((acc, item) => Math.min(acc, getter(item) || 0), 0) - 1 - getSecureRandomIfPossible();
  }
  function end(items2) {
    return items2.reduce((acc, item) => Math.max(acc, getter(item) || 0), 0) + 1 + getSecureRandomIfPossible();
  }
  function between(lower, upper) {
    if (lower == null)
      lower = (upper ?? 0) - 1;
    if (upper == null)
      upper = (lower ?? 0) + 1;
    const distance = upper - lower;
    const middle = lower + distance / 2;
    const fuzzy = distance * 0.01 * (getSecureRandomIfPossible() - 0.5);
    return middle + fuzzy;
  }
  function move(newIndex, oldIndex, sortableItems) {
    const count = sortableItems.length;
    const moveLower = newIndex < oldIndex;
    if (count <= 0 || newIndex >= count - 1)
      return end(sortableItems);
    if (newIndex <= 0)
      return start(sortableItems);
    sortableItems = items([...sortableItems]);
    const step = moveLower ? -1 : 0;
    const lower = getter(sortableItems[newIndex + step]) || 0;
    const upper = getter(sortableItems[newIndex + step + 1]) || 0;
    const distance = upper - lower;
    if (distance === 0) {
      if (moveLower)
        return start(sortableItems);
      return end(sortableItems);
    }
    const middle = lower + distance / 2;
    const fuzzy = distance * 0.01 * (getSecureRandomIfPossible() - 0.5);
    return middle + fuzzy;
  }
  return {
    start,
    end,
    between,
    move,
    items
  };
}

export {
  useSorted
};
//# sourceMappingURL=chunk-NYCGHEIN.js.map