import {
  LogLevelAlias,
  LogLevelAll,
  LogLevelOff
} from "./chunk-YX6CL4KH.js";
import {
  isString
} from "./chunk-AY5LGXTC.js";

// src/common/log/log-filter.ts
function getNamespaceFilterString(defaultNamespaceFilter) {
  if (defaultNamespaceFilter === true || defaultNamespaceFilter === "true" || defaultNamespaceFilter === "1" || typeof defaultNamespaceFilter === "number" && defaultNamespaceFilter !== 0) {
    defaultNamespaceFilter = "*";
  } else if (defaultNamespaceFilter === false || defaultNamespaceFilter === "false" || defaultNamespaceFilter === 0 || defaultNamespaceFilter === "0" || defaultNamespaceFilter == null || defaultNamespaceFilter === "null" || defaultNamespaceFilter === "undefined") {
    defaultNamespaceFilter = "";
  } else {
    defaultNamespaceFilter = String(defaultNamespaceFilter);
  }
  return defaultNamespaceFilter;
}
function getDefaultNamespaceFilter() {
  return getNamespaceFilterString(
    typeof process !== "undefined" ? process.env.ZEED ?? process.env.DEBUG : typeof localStorage !== "undefined" ? localStorage.zeed ?? localStorage.debug : "*"
  );
}
function useNamespaceFilter(filter = getDefaultNamespaceFilter()) {
  let fn;
  const reject = [];
  const accept = [];
  if (!filter) {
    fn = function(_name) {
      return false;
    };
  } else if (filter === "*") {
    fn = function(_name) {
      return true;
    };
  } else {
    let i;
    const split = filter.split(/[\s,]+/);
    const len = split.length;
    for (i = 0; i < len; i++) {
      if (!split[i]) {
        continue;
      }
      const template = split[i].replace(/\*/g, ".*?");
      if (template[0] === "-")
        reject.push(new RegExp(`^${template.substr(1)}`));
      else
        accept.push(new RegExp(`^${template}`));
    }
    fn = function(name) {
      if (reject.length === 0 && accept.length === 0)
        return true;
      let i2, len2;
      for (i2 = 0, len2 = reject.length; i2 < len2; i2++) {
        if (reject[i2].test(name))
          return false;
      }
      for (i2 = 0, len2 = accept.length; i2 < len2; i2++) {
        if (accept[i2].test(name))
          return true;
      }
      return false;
    };
  }
  fn.accept = accept;
  fn.reject = reject;
  fn.filter = filter;
  return fn;
}
function getDefaultLevelFilter() {
  return typeof process !== "undefined" ? process.env.ZEED_LEVEL ?? process.env.LEVEL ?? process.env.DEBUG_LEVEL : typeof localStorage !== "undefined" ? localStorage.zeed_level ?? localStorage.level ?? localStorage.debug_level : void 0;
}
function parseLogLevel(filter) {
  if (filter === false)
    return LogLevelOff;
  if (typeof filter === "number")
    return filter;
  if (typeof filter === "string") {
    const l = LogLevelAlias[filter.toLocaleLowerCase().trim()];
    if (l != null)
      return l;
  }
  return LogLevelAll;
}
function useLevelFilter(filter = getDefaultLevelFilter()) {
  const filterLevel = parseLogLevel(filter);
  return (level) => level >= filterLevel;
}
function joinLogStrings(...messages) {
  if (isString(messages[1]))
    return [`${String(messages[0])} ${String(messages[1])}`, ...messages.slice(2)];
  return messages;
}

export {
  getNamespaceFilterString,
  useNamespaceFilter,
  parseLogLevel,
  useLevelFilter,
  joinLogStrings
};
//# sourceMappingURL=chunk-UJR57SSR.js.map