import {
  createPromise
} from "./chunk-L324TYGN.js";

// src/common/msg/rpc.ts
var rpcCounter = 1;
var defaultSerialize = (i) => i;
var defaultDeserialize = defaultSerialize;
function setupRPCBasic(options, functions, eventNames = []) {
  const {
    log,
    post,
    on,
    serialize = defaultSerialize,
    deserialize = defaultDeserialize,
    timeout = 6e4,
    onError,
    onTimeoutError,
    onlyEvents = false,
    exceptions = true,
    stringHashPool
  } = options;
  if (stringHashPool) {
    Object.keys(functions).forEach(stringHashPool.hash);
  }
  function checkEventNames(eventNames2) {
  }
  checkEventNames(eventNames);
  function registerFunctions(additionalFunctions) {
    Object.assign(functions, additionalFunctions ?? {});
    if (stringHashPool)
      Object.keys(additionalFunctions).forEach(stringHashPool.hash);
  }
  function registerEventNames(additionalEventNames) {
    checkEventNames(additionalEventNames);
    eventNames.push(...additionalEventNames);
  }
  const rpcPromiseMap = /* @__PURE__ */ new Map();
  on(async (data) => {
    try {
      const msg = await deserialize(data);
      const mode = msg?.[0];
      const id = mode === 2 /* event */ ? 0 : msg?.[1];
      const [method, ...args] = msg.slice(mode === 2 /* event */ ? 1 : 2);
      const methodName = stringHashPool?.stringForHash(method) ?? method;
      if (mode === 1 /* request */ || mode === 2 /* event */) {
        let result, error;
        if (method != null) {
          try {
            const fn = functions[methodName];
            result = await fn(...args);
          } catch (e) {
            error = String(e);
          }
        } else {
          error = "Method implementation missing";
        }
        if (error) {
          log?.warn("error", msg, error);
          onError?.(error, method ?? "", args);
        }
        if (id > 0) {
          const data2 = await serialize(error ? [4 /* reject */, id, error] : [3 /* resolve */, id, result]);
          await post(data2);
        }
      } else if (id) {
        const promise = rpcPromiseMap.get(id);
        if (promise != null) {
          clearTimeout(promise.timeoutId);
          if (mode === 4 /* reject */ && exceptions === true)
            promise.reject(method);
          else
            promise.resolve(method);
        }
        rpcPromiseMap.delete(id);
      }
    } catch (err) {
      log?.warn("Error on handling RPC data. Invalid?", err, data);
    }
  });
  const proxyHandler = {
    get(_, methodName) {
      const method = stringHashPool?.hash(methodName) ?? methodName;
      const sendEvent = async (...args) => await post(await serialize([2 /* event */, method, ...args]));
      if (onlyEvents || eventNames.includes(methodName)) {
        sendEvent.asEvent = sendEvent;
        return sendEvent;
      }
      const sendCall = async (...args) => {
        const [promise, resolve, reject] = createPromise();
        const id = rpcCounter++;
        let timeoutId;
        if (timeout >= 0) {
          timeoutId = setTimeout(() => {
            try {
              onTimeoutError?.(methodName, args);
              throw new Error(`rpc timeout on calling "${methodName}"`);
            } catch (e) {
              if (exceptions === true)
                reject(e);
              else
                resolve(void 0);
            }
            rpcPromiseMap.delete(id);
          }, timeout).unref?.();
        }
        rpcPromiseMap.set(id, { resolve, reject, timeoutId });
        const data = await serialize([1 /* request */, id, method, ...args]);
        await post(data);
        return promise;
      };
      sendCall.asEvent = sendEvent;
      return sendCall;
    }
  };
  return {
    post,
    serialize,
    rpcPromiseMap,
    proxyHandler,
    registerFunctions,
    registerEventNames
  };
}
function useRPC(functions, options) {
  const { eventNames = [] } = options;
  const { proxyHandler } = setupRPCBasic(options, functions, eventNames);
  return new Proxy({}, proxyHandler);
}
function useRPCHub(options) {
  const eventNames = [];
  const functions = {};
  const {
    proxyHandler,
    registerFunctions,
    registerEventNames
  } = setupRPCBasic(options, functions, eventNames);
  function createRPCProxy() {
    return new Proxy({}, proxyHandler);
  }
  return function(additionalFunctions, additionalEventNames = []) {
    registerFunctions(additionalFunctions ?? {});
    registerEventNames(additionalEventNames);
    return createRPCProxy();
  };
}

export {
  useRPC,
  useRPCHub
};
//# sourceMappingURL=chunk-VNLRM2QZ.js.map