// src/common/data/json.ts
var _sortedReplacer = (key, value) => value instanceof Object && !Array.isArray(value) ? Object.keys(value).sort().reduce((sorted, key2) => {
  sorted[key2] = value[key2];
  return sorted;
}, {}) : value;
function jsonStringifySorted(obj, indent = void 0) {
  return JSON.stringify(obj, _sortedReplacer, indent);
}
function serializer(replacer, cycleReplacer) {
  const stack = [];
  const keys = [];
  if (cycleReplacer == null) {
    cycleReplacer = function(_key, value) {
      if (stack[0] === value)
        return "[Circular ~]";
      return `[Circular ~.${keys.slice(0, stack.indexOf(value)).join(".")}]`;
    };
  }
  return function(key, value) {
    if (stack.length > 0) {
      const thisPos = stack.indexOf(this);
      ~thisPos ? stack.splice(thisPos + 1) : stack.push(this);
      ~thisPos ? keys.splice(thisPos, Number.POSITIVE_INFINITY, key) : keys.push(key);
      if (~stack.indexOf(value))
        value = cycleReplacer?.call(this, key, value);
    } else {
      stack.push(value);
    }
    try {
      return replacer == null ? value : replacer.call(this, key, value);
    } catch (err) {
    }
    return String(value);
  };
}
function jsonStringifySafe(obj, replacer, spaces, cycleReplacer) {
  return JSON.stringify(
    obj,
    serializer(replacer ?? void 0, cycleReplacer),
    spaces ?? void 0
  );
}
var jsonStringify = jsonStringifySafe;
var suspectProtoRx = /"(?:_|\\u005[Ff])(?:_|\\u005[Ff])(?:p|\\u0070)(?:r|\\u0072)(?:o|\\u006[Ff])(?:t|\\u0074)(?:o|\\u006[Ff])(?:_|\\u005[Ff])(?:_|\\u005[Ff])"\s*:/;
var suspectConstructorRx = /"(?:c|\\u0063)(?:o|\\u006[Ff])(?:n|\\u006[Ee])(?:s|\\u0073)(?:t|\\u0074)(?:r|\\u0072)(?:u|\\u0075)(?:c|\\u0063)(?:t|\\u0074)(?:o|\\u006[Ff])(?:r|\\u0072)"\s*:/;
var JsonSigRx = /^["{[]|^-?[0-9][0-9.]{0,14}$/;
function jsonParseTransform(key, value) {
  if (key === "__proto__" || key === "constructor")
    return;
  return value;
}
function jsonParse(val) {
  if (typeof val !== "string")
    return val;
  const _lval = val.toLowerCase();
  if (_lval === "true")
    return true;
  if (_lval === "false")
    return false;
  if (_lval === "null")
    return null;
  if (_lval === "nan")
    return Number.NaN;
  if (_lval === "infinity")
    return Number.POSITIVE_INFINITY;
  if (_lval === "undefined")
    return void 0;
  if (!JsonSigRx.test(val))
    return val;
  try {
    if (suspectProtoRx.test(val) || suspectConstructorRx.test(val))
      return JSON.parse(val, jsonParseTransform);
    return JSON.parse(val);
  } catch (_e) {
    return val;
  }
}

export {
  jsonStringifySorted,
  jsonStringifySafe,
  jsonStringify,
  jsonParse
};
//# sourceMappingURL=chunk-VWBTJP5F.js.map