import "../../chunk-HMRSQHLY.js";
import "../../chunk-UMUHNSGZ.js";
import "../../chunk-3ESD64QY.js";
import {
  bitfield,
  createBinaryStreamDecoder,
  createBinaryStreamEncoder,
  encodeJson
} from "../../chunk-YUEJKLRT.js";
import "../../chunk-MO24G7VK.js";
import "../../chunk-QQSABUQG.js";
import "../../chunk-RNL46FQ3.js";
import "../../chunk-MWUFUBY5.js";
import "../../chunk-GKKLBSFA.js";
import "../../chunk-264HKVNG.js";
import "../../chunk-6FVATU5D.js";
import "../../chunk-AJCIHTGI.js";
import "../../chunk-FLFB2K34.js";
import "../../chunk-HST4VI64.js";
import "../../chunk-A7SUGWC3.js";
import "../../chunk-PDBCA7WB.js";
import "../../chunk-B44DP4LU.js";
import "../../chunk-UE2PB4HJ.js";
import "../../chunk-HH5MZIMF.js";
import "../../chunk-VNLRM2QZ.js";
import "../../chunk-UYLJHAX3.js";
import "../../chunk-YFNV56TG.js";
import "../../chunk-YVLJVKPH.js";
import "../../chunk-B47EOWH4.js";
import "../../chunk-XH3UHC3W.js";
import "../../chunk-NHKHMG5M.js";
import "../../chunk-KUFV2R7W.js";
import "../../chunk-5OVSRAPG.js";
import "../../chunk-OGMPYNGB.js";
import "../../chunk-WEBXXRYZ.js";
import "../../chunk-GPE2GR6Y.js";
import "../../chunk-TSCDX4AS.js";
import "../../chunk-D6B6MYVG.js";
import "../../chunk-XWWQZH6C.js";
import "../../chunk-Y7J6ADHV.js";
import "../../chunk-OKUAPZFI.js";
import "../../chunk-QS2OVW4B.js";
import "../../chunk-7IUVQQ4S.js";
import "../../chunk-MIZOLME5.js";
import "../../chunk-UJR57SSR.js";
import "../../chunk-YX6CL4KH.js";
import "../../chunk-I45WP5PM.js";
import "../../chunk-ZFRTRIT4.js";
import "../../chunk-CFICINSP.js";
import "../../chunk-3KKFLSLG.js";
import "../../chunk-5Y3HYG6B.js";
import "../../chunk-FPJHSFML.js";
import "../../chunk-XSB2WAW2.js";
import "../../chunk-NYCGHEIN.js";
import "../../chunk-AS5LR4AI.js";
import "../../chunk-2H4XRKWS.js";
import "../../chunk-NSJKG6AJ.js";
import "../../chunk-XHROZN2O.js";
import "../../chunk-3SMFSMCY.js";
import "../../chunk-X2DIUKLP.js";
import "../../chunk-KCHV27UP.js";
import "../../chunk-DUQ7DD4G.js";
import "../../chunk-2HWPZ6ZE.js";
import "../../chunk-DGP32WEQ.js";
import "../../chunk-NS46DWU4.js";
import "../../chunk-73CVRDI7.js";
import "../../chunk-FL5CT6MC.js";
import "../../chunk-FQCORE5F.js";
import "../../chunk-L324TYGN.js";
import "../../chunk-MRFHKDNG.js";
import "../../chunk-HLRQ5H3N.js";
import "../../chunk-DXSTF7NX.js";
import "../../chunk-AY5LGXTC.js";
import "../../chunk-OQSDTQAF.js";
import "../../chunk-SOTGICOC.js";
import "../../chunk-DUON5DN5.js";
import "../../chunk-GY34N3KU.js";
import "../../chunk-IZT6OHMS.js";
import "../../chunk-JJD2XTS2.js";
import "../../chunk-TYWNSO7K.js";
import "../../chunk-ZMFW3O35.js";
import "../../chunk-5BQNKE5C.js";
import "../../chunk-7NSVDPHN.js";
import {
  Uint8ArrayToHexDump,
  equalBinary,
  toHex
} from "../../chunk-WG6ZJDFQ.js";
import "../../chunk-VWBTJP5F.js";
import "../../chunk-LRAR7IPU.js";

// src/common/bin/index.spec.ts
describe("encoder", () => {
  it("should write a stream", () => {
    const stream = createBinaryStreamEncoder();
    stream.writeUint32(1);
    stream.write({ a: "99" });
    stream.writeBytes([1, 2, 3], 3);
    stream.write(123);
    const bin = stream.getUint8Array();
    expect(Uint8ArrayToHexDump(bin)).toMatchInlineSnapshot(`
      "0000  01 00 00 00 76 01 01 61 77 02 39 39 01 02 03 7d  ....v..aw.99...}
      0010  bb 01                                            \xBB.              "
    `);
    expect(stream.getLength()).toBe(18);
    const readStream = createBinaryStreamDecoder(bin);
    expect(readStream.getOffset()).toBe(0);
    expect(readStream.readUint32()).toBe(1);
    expect(readStream.getOffset()).toBe(4);
    expect(readStream.read()).toEqual({ a: "99" });
    expect(readStream.readBytes(3)).toMatchInlineSnapshot(`
Uint8Array [
  1,
  2,
  3,
]
`);
    expect(readStream.read()).toBe(123);
    expect(readStream.getOffset()).toBe(bin.length);
  });
  it("should bitfield", () => {
    const bf = bitfield(1);
    bf.setBit(4);
    expect(bf.getValue()).toBe(17);
    bf.setBit(0, false);
    expect(bf.getValue()).toBe(16);
    bf.setBit(1);
    bf.setBit(5);
    bf.setBit(16);
    expect(bf.getValue().toString(2)).toMatchInlineSnapshot(
      '"10000000000110010"'
    );
    expect(bf.getValue()).toBe(65586);
    expect(bf.getBit(0)).toBe(false);
    expect(bf.getBit(4)).toBe(true);
    bf.toggleBit(4);
    expect(bf.getBit(4)).toBe(false);
    expect(bf.getValue()).toBe(65570);
  });
  it("should var bin", () => {
    function enc(v) {
      const e = createBinaryStreamEncoder();
      e.writeIntVar(v);
      return toHex(e.getUint8Array());
    }
    expect(enc(1)).toMatchInlineSnapshot('"01"');
    expect(enc(128)).toMatchInlineSnapshot('"8002"');
    expect(enc(-1)).toMatchInlineSnapshot('"41"');
    expect(enc(-691529286)).toMatchInlineSnapshot('"c699bf9305"');
    expect(enc(691529286)).toMatchInlineSnapshot('"8699bf9305"');
  });
  it("should var bin uint", () => {
    function enc(v) {
      const e = createBinaryStreamEncoder();
      e.writeUintVar(v);
      return toHex(e.getUint8Array());
    }
    expect(enc(1)).toMatchInlineSnapshot('"01"');
    expect(enc(127)).toMatchInlineSnapshot('"7f"');
    expect(enc(128)).toMatchInlineSnapshot(`"8001"`);
    expect(enc(255)).toMatchInlineSnapshot('"ff01"');
    expect(enc(256)).toMatchInlineSnapshot('"8002"');
    expect(enc(691529286)).toMatchInlineSnapshot('"c6ccdfc902"');
  });
  it("should be consistent", () => {
    const bin1 = encodeJson({
      a: 1,
      b: 2
    });
    const bin2 = encodeJson({
      b: 2,
      a: 1
    });
    expect(equalBinary(bin1, bin2)).toBe(true);
  });
});
//# sourceMappingURL=index.spec.js.map