"use strict";





var _chunkIMVRN3AUcjs = require('../../chunk-IMVRN3AU.cjs');
require('../../chunk-EBDUTZIB.cjs');

// src/common/crypto/xaes.spec.ts
describe("xaes.spec", () => {
  it("xaes generateKey/encrypt/decrypt", async () => {
    const key = await _chunkIMVRN3AUcjs.generateKey.call(void 0, );
    const iv = new Uint8Array(24).fill(1);
    const data = new Uint8Array(122).fill(2);
    const additionalData = new Uint8Array(16).fill(3);
    const params = { iv, additionalData };
    const encrypted = await _chunkIMVRN3AUcjs.encrypt.call(void 0, params, key, data);
    const decrypted = await _chunkIMVRN3AUcjs.decrypt.call(void 0, params, key, encrypted);
    expect(decrypted).toEqual(data.buffer);
  });
  it("xaes importKey, exportKey", async () => {
    const key = new Uint8Array(32).fill(4);
    const imported = await _chunkIMVRN3AUcjs.importKey.call(void 0, "raw", key, true);
    const exported = await _chunkIMVRN3AUcjs.exportKey.call(void 0, "raw", imported);
    expect(exported).toEqual(key.buffer);
  });
  it("xaes test vector", async () => {
    const nonce = new TextEncoder().encode("ABCDEFGHIJKLMNOPQRSTUVWX");
    const plaintext = new TextEncoder().encode("XAES-256-GCM");
    const key = await _chunkIMVRN3AUcjs.importKey.call(void 0, 
      "raw",
      new Uint8Array(32).fill(1),
      false
    );
    const ciphertext = await _chunkIMVRN3AUcjs.encrypt.call(void 0, { iv: nonce }, key, plaintext);
    const got = Array.from(new Uint8Array(ciphertext), (byte) => byte.toString(16).padStart(2, "0")).join("");
    const expected = "ce546ef63c9cc60765923609b33a9a1974e96e52daf2fcf7075e2271";
    expect(got).toEqual(expected);
    const decrypted = await _chunkIMVRN3AUcjs.decrypt.call(void 0, { iv: nonce }, key, ciphertext);
    expect(new Uint8Array(decrypted)).toEqual(plaintext);
  });
  it("xaes test vector with additional data", async () => {
    const key = await _chunkIMVRN3AUcjs.importKey.call(void 0, 
      "raw",
      new Uint8Array(32).fill(3),
      false
    );
    const aad = new TextEncoder().encode("c2sp.org/XAES-256-GCM");
    const nonce = new TextEncoder().encode("ABCDEFGHIJKLMNOPQRSTUVWX");
    const plaintext = new TextEncoder().encode("XAES-256-GCM");
    const ciphertext = await _chunkIMVRN3AUcjs.encrypt.call(void 0, { iv: nonce, additionalData: aad }, key, plaintext);
    const got = Array.from(new Uint8Array(ciphertext), (byte) => byte.toString(16).padStart(2, "0")).join("");
    const expected = "986ec1832593df5443a179437fd083bf3fdb41abd740a21f71eb769d";
    expect(got).toEqual(expected);
    const decrypted = await _chunkIMVRN3AUcjs.decrypt.call(void 0, { iv: nonce, additionalData: aad }, key, ciphertext);
    expect(new Uint8Array(decrypted)).toEqual(plaintext);
  });
});
//# sourceMappingURL=xaes.spec.cjs.map