import {
  Emitter
} from "../../chunk-OGMPYNGB.js";
import {
  useDispose
} from "../../chunk-GPE2GR6Y.js";
import "../../chunk-TSCDX4AS.js";
import "../../chunk-D6B6MYVG.js";
import "../../chunk-XWWQZH6C.js";
import "../../chunk-Y7J6ADHV.js";
import "../../chunk-OKUAPZFI.js";
import "../../chunk-QS2OVW4B.js";
import "../../chunk-MIZOLME5.js";
import "../../chunk-UJR57SSR.js";
import "../../chunk-YX6CL4KH.js";
import "../../chunk-I45WP5PM.js";
import "../../chunk-ZFRTRIT4.js";
import "../../chunk-CFICINSP.js";
import "../../chunk-3KKFLSLG.js";
import "../../chunk-5Y3HYG6B.js";
import "../../chunk-FPJHSFML.js";
import "../../chunk-XSB2WAW2.js";
import "../../chunk-NYCGHEIN.js";
import "../../chunk-AS5LR4AI.js";
import "../../chunk-2H4XRKWS.js";
import "../../chunk-NSJKG6AJ.js";
import "../../chunk-XHROZN2O.js";
import "../../chunk-3SMFSMCY.js";
import "../../chunk-X2DIUKLP.js";
import "../../chunk-KCHV27UP.js";
import {
  objectInclusivePick,
  objectMap,
  objectMergeDisposable,
  objectOmit,
  objectPick,
  objectPlain
} from "../../chunk-DUQ7DD4G.js";
import "../../chunk-2HWPZ6ZE.js";
import "../../chunk-DGP32WEQ.js";
import "../../chunk-NS46DWU4.js";
import "../../chunk-73CVRDI7.js";
import "../../chunk-FL5CT6MC.js";
import "../../chunk-FQCORE5F.js";
import "../../chunk-L324TYGN.js";
import "../../chunk-MRFHKDNG.js";
import "../../chunk-HLRQ5H3N.js";
import "../../chunk-DXSTF7NX.js";
import {
  isBoolean,
  isNotNull
} from "../../chunk-AY5LGXTC.js";
import "../../chunk-OQSDTQAF.js";
import "../../chunk-SOTGICOC.js";
import "../../chunk-DUON5DN5.js";
import "../../chunk-GY34N3KU.js";
import "../../chunk-IZT6OHMS.js";
import "../../chunk-JJD2XTS2.js";
import "../../chunk-TYWNSO7K.js";
import "../../chunk-ZMFW3O35.js";
import "../../chunk-5BQNKE5C.js";
import "../../chunk-7NSVDPHN.js";
import "../../chunk-WG6ZJDFQ.js";
import "../../chunk-VWBTJP5F.js";
import "../../chunk-LRAR7IPU.js";

// src/common/data/object.spec.ts
describe("object.spec", () => {
  it("should map it", async () => {
    const sample = {
      a: 1,
      b: 2
    };
    expect(objectMap(sample, (k, v) => v + 10)).toMatchInlineSnapshot(`
      Object {
        "a": 11,
        "b": 12,
      }
    `);
    expect(objectMap(sample, (k, v) => [`${k}_${v}`, k])).toMatchInlineSnapshot(`
        Object {
          "a_1": "a",
          "b_2": "b",
        }
      `);
  });
  it("should merge", async () => {
    const emitter = new Emitter();
    const obj = {
      dispose: useDispose(),
      f() {
        return 42;
      }
    };
    let x = 1;
    obj.dispose.add(() => x++);
    const m = objectMergeDisposable(emitter, obj);
    expect(m.f()).toBe(42);
    m.on("a", () => x++);
    void m.emit("a");
    expect(x).toBe(2);
    await m.dispose();
    expect(x).toBe(3);
  });
  it("should omit and pick", () => {
    const o = { a: 1, b: 2, c: 3, d: 4 };
    expect(objectPick(o, "a", "c")).toMatchInlineSnapshot(`
      Object {
        "a": 1,
        "c": 3,
      }
    `);
    expect(objectOmit(o, "a", "c")).toMatchInlineSnapshot(`
      Object {
        "b": 2,
        "d": 4,
      }
    `);
    expect(objectInclusivePick(o, "a", "c", "x")).toMatchInlineSnapshot(`
      Object {
        "a": 1,
        "c": 3,
        "x": undefined,
      }
    `);
  });
});
describe("objectPlain", () => {
  it("should return the plain object", () => {
    const obj = {
      a: 1,
      b: {
        c: 2,
        d: [3, 4]
      }
    };
    const result = objectPlain(obj);
    expect(result).toEqual(obj);
  });
  it("should handle bool", async () => {
    const x = objectPlain({ test: true, fdsf: { fsdafs: false } }, {
      transformer: (obj) => {
        if (isBoolean(obj))
          return +obj;
      }
    });
    expect(x).toMatchInlineSnapshot(`
      Object {
        "fdsf": Object {
          "fsdafs": 0,
        },
        "test": 1,
      }
    `);
  });
  it("should handle circular references", () => {
    const obj = {
      a: 1
    };
    obj.b = obj;
    const result = objectPlain(obj, { circleValue: "*** CIRCULAR ***" });
    expect(result).toMatchInlineSnapshot(`
      Object {
        "a": 1,
        "b": "*** CIRCULAR ***",
      }
    `);
  });
  it("should handle nested objects", () => {
    const obj = {
      a: 1,
      b: {
        c: 2,
        d: {
          e: 3
        }
      }
    };
    const result = objectPlain(obj);
    expect(result).toEqual(obj);
  });
  it("should handle arrays", () => {
    const obj = {
      a: 1,
      b: [2, 3, 4]
    };
    const result = objectPlain(obj);
    expect(result).toEqual(obj);
  });
  it("should handle max depth", () => {
    const obj = {
      a: {
        b: {
          c: {
            d: {
              e: 1
            }
          }
        }
      }
    };
    const result = objectPlain(obj, { maxDepth: 3, maxDepthValue: "*** MAX DEPTH ***" });
    expect(result).toEqual({
      a: {
        b: {
          c: {
            d: "*** MAX DEPTH ***"
          }
        }
      }
    });
  });
  it("should handle removeUndefined", () => {
    const obj = {
      a: 1,
      b: void 0,
      c: [1, void 0]
    };
    const result = objectPlain(obj, { filter: isNotNull });
    expect(result).toEqual({ a: 1, c: [1] });
  });
  it("should also support crazy stuff", () => {
    function fn() {
      this.y = 1;
    }
    fn.prototype.x = 2;
    fn.z = 6;
    class Klass {
      constructor(name) {
        this.name = name ?? "test";
      }
    }
    const obj = {
      a: 1,
      b: {
        x: Symbol("x"),
        y: BigInt(123),
        fn,
        bool: true,
        nan: Number.NaN,
        inf: Number.POSITIVE_INFINITY,
        err: new Error("err"),
        set: /* @__PURE__ */ new Set([1, { x: 1 }, 3]),
        rx: /.*?.test/gim,
        map: /* @__PURE__ */ new Map([
          ["a", 1],
          ["b", 2],
          [true, "bool"]
        ]),
        date: new Date(Date.UTC(2024, 0, 1, 12)),
        weakMap: /* @__PURE__ */ new WeakMap(),
        uint8: new Uint8Array([1, 2, 3]),
        uint16: new Uint16Array([1, 2, 3]),
        c: 2,
        d: [3, 4, 5],
        Klass,
        newKlass: new Klass("testNewKlass")
      }
    };
    const result = objectPlain(obj, {
      keepAsIs: (o) => o instanceof Uint8Array,
      errorTrace: false,
      transformer(obj2) {
        if (obj2 instanceof Date)
          return { __timestamp: obj2.getTime() };
        if (isBoolean(obj2))
          return +obj2;
      }
    });
    expect(result).toMatchInlineSnapshot(`
      Object {
        "a": 1,
        "b": Object {
          "Klass": Object {
            "__class": "Function",
          },
          "bool": 1,
          "c": 2,
          "d": Array [
            3,
            4,
            5,
          ],
          "date": Object {
            "__timestamp": 1704110400000,
          },
          "err": Object {
            "__class": "Error",
            "cause": undefined,
            "message": "err",
            "name": "Error",
            "stack": undefined,
          },
          "fn": Object {
            "__class": "Function",
            "z": 6,
          },
          "inf": Infinity,
          "map": Object {
            "a": 1,
            "b": 2,
            "true": "bool",
          },
          "nan": NaN,
          "newKlass": Object {
            "__class": "Klass",
            "name": "testNewKlass",
          },
          "rx": Object {
            "__class": "RegExp",
            "source": "/.*?.test/gim",
          },
          "set": Array [
            1,
            Object {
              "x": 1,
            },
            3,
          ],
          "uint16": Array [
            1,
            2,
            3,
          ],
          "uint8": Uint8Array [
            1,
            2,
            3,
          ],
          "weakMap": Object {
            "__class": "WeakMap",
          },
          "x": "Symbol(x)",
          "y": 123n,
        },
      }
    `);
    const result2 = objectPlain(obj);
    expect(objectPlain(result2)).toEqual(result2);
  });
});
//# sourceMappingURL=object.spec.js.map