import "../chunk-UE2PB4HJ.js";
import "../chunk-HH5MZIMF.js";
import "../chunk-VNLRM2QZ.js";
import "../chunk-UYLJHAX3.js";
import "../chunk-YFNV56TG.js";
import "../chunk-YVLJVKPH.js";
import "../chunk-B47EOWH4.js";
import "../chunk-XH3UHC3W.js";
import "../chunk-NHKHMG5M.js";
import "../chunk-KUFV2R7W.js";
import "../chunk-5OVSRAPG.js";
import "../chunk-OGMPYNGB.js";
import "../chunk-WEBXXRYZ.js";
import {
  useDefer,
  useDispose
} from "../chunk-GPE2GR6Y.js";
import "../chunk-TSCDX4AS.js";
import "../chunk-D6B6MYVG.js";
import "../chunk-XWWQZH6C.js";
import {
  DefaultLogger
} from "../chunk-Y7J6ADHV.js";
import "../chunk-OKUAPZFI.js";
import "../chunk-QS2OVW4B.js";
import "../chunk-7IUVQQ4S.js";
import "../chunk-MIZOLME5.js";
import "../chunk-UJR57SSR.js";
import "../chunk-YX6CL4KH.js";
import "../chunk-I45WP5PM.js";
import "../chunk-ZFRTRIT4.js";
import "../chunk-CFICINSP.js";
import "../chunk-3KKFLSLG.js";
import "../chunk-5Y3HYG6B.js";
import "../chunk-FPJHSFML.js";
import "../chunk-XSB2WAW2.js";
import "../chunk-NYCGHEIN.js";
import "../chunk-AS5LR4AI.js";
import "../chunk-2H4XRKWS.js";
import "../chunk-NSJKG6AJ.js";
import "../chunk-XHROZN2O.js";
import "../chunk-3SMFSMCY.js";
import "../chunk-X2DIUKLP.js";
import "../chunk-KCHV27UP.js";
import "../chunk-DUQ7DD4G.js";
import "../chunk-2HWPZ6ZE.js";
import "../chunk-DGP32WEQ.js";
import "../chunk-NS46DWU4.js";
import "../chunk-73CVRDI7.js";
import "../chunk-FL5CT6MC.js";
import "../chunk-FQCORE5F.js";
import {
  sleep
} from "../chunk-L324TYGN.js";
import "../chunk-MRFHKDNG.js";
import "../chunk-HLRQ5H3N.js";
import "../chunk-DXSTF7NX.js";
import "../chunk-AY5LGXTC.js";
import "../chunk-OQSDTQAF.js";
import "../chunk-SOTGICOC.js";
import "../chunk-DUON5DN5.js";
import "../chunk-GY34N3KU.js";
import "../chunk-IZT6OHMS.js";
import "../chunk-JJD2XTS2.js";
import "../chunk-TYWNSO7K.js";
import "../chunk-ZMFW3O35.js";
import "../chunk-5BQNKE5C.js";
import "../chunk-7NSVDPHN.js";
import "../chunk-WG6ZJDFQ.js";
import "../chunk-VWBTJP5F.js";
import {
  __callDispose,
  __using
} from "../chunk-LRAR7IPU.js";

// src/common/dispose-defer.spec.ts
var log = DefaultLogger("dispose-test");
describe("dispose", () => {
  it("should dispose correctly", async () => {
    const disposeCalls = [];
    const dispose = useDispose("a");
    const y = dispose.track({
      dispose() {
        disposeCalls.push(1);
      }
    });
    dispose.track(() => {
      disposeCalls.push(2);
    });
    const x = {
      async dispose() {
        disposeCalls.push(3);
      }
    };
    dispose.track(x);
    dispose.track();
    dispose.track(async () => {
      disposeCalls.push(4);
    });
    expect(disposeCalls).toEqual([]);
    expect(dispose.getSize()).toEqual(4);
    await dispose.untrack(x);
    expect(disposeCalls).toEqual([3]);
    expect(dispose.getSize()).toEqual(3);
    await dispose.untrack(x);
    expect(disposeCalls).toEqual([3]);
    expect(dispose.getSize()).toEqual(3);
    y?.();
    y?.();
    await dispose.untrack(x);
    expect(disposeCalls).toEqual([3, 1]);
    expect(dispose.getSize()).toEqual(2);
    await dispose.dispose();
    expect(disposeCalls).toEqual([3, 1, 4, 2]);
    expect(dispose.getSize()).toEqual(0);
    await dispose();
    expect(disposeCalls).toEqual([3, 1, 4, 2]);
    expect(dispose.getSize()).toEqual(0);
  });
  it("should be a fancy dispose itself", () => {
    let x = 1;
    class Some {
      constructor() {
        this.dispose = useDispose(log);
        this.dispose.track(() => {
          x = 2;
        });
      }
    }
    const obj = new Some();
    expect(x).toBe(1);
    void obj.dispose();
    expect(x).toBe(2);
  });
  it("should defer lifo", async () => {
    const stack = [];
    const defer = useDefer({ mode: "lifo" });
    defer.add(() => stack.push("a"));
    defer.add(() => stack.push("b"));
    defer.add(() => stack.push("c"));
    expect(stack).toEqual([]);
    void defer(true);
    expect(stack).toEqual(["c", "b", "a"]);
  });
  it("should defer fifo", async () => {
    const stack = [];
    const defer = useDefer({ mode: "fifo" });
    defer.add(() => stack.push("a"));
    defer.add(async () => stack.push("b"));
    defer.add(() => stack.push("c"));
    expect(stack).toEqual([]);
    await defer();
    expect(stack).toEqual(["a", "b", "c"]);
  });
  it("should dispose sync", async () => {
    const stack = [];
    const dispose = useDispose();
    dispose.add(() => stack.push("a"));
    dispose.add(() => stack.push("b"));
    dispose.add(() => stack.push("c"));
    expect(stack).toEqual([]);
    await dispose(true);
    expect(stack).toEqual(["c", "b", "a"]);
  });
  it("should dispose sync using using", async () => {
    const stack = [];
    function helper() {
      var _stack = [];
      try {
        const dispose = __using(_stack, useDispose());
        dispose.add(() => stack.push("a"));
        dispose.add(() => stack.push("b"));
        dispose.add(() => stack.push("c"));
        expect(stack).toEqual([]);
      } catch (_) {
        var _error = _, _hasError = true;
      } finally {
        __callDispose(_stack, _error, _hasError);
      }
    }
    helper();
    expect(stack).toEqual(["c", "b", "a"]);
  });
  it("should dispose sync 2", async () => {
    const stack = [];
    const dispose = useDispose();
    dispose.add(() => stack.push("a"));
    dispose.add(() => stack.push("b"));
    dispose.add(async () => {
      await sleep(1);
      stack.push("c");
    });
    expect(stack).toEqual([]);
    expect(dispose.sync).toThrowError();
  });
  it("should use using", async () => {
    const history = [];
    function log2(s) {
      history.push(s);
    }
    class TempFile {
      constructor(path) {
        log2("constructor");
      }
      [Symbol.dispose]() {
        log2("dispose");
      }
    }
    function fn() {
      var _stack = [];
      try {
        const f = __using(_stack, new TempFile("abc"));
        log2("fn return");
      } catch (_) {
        var _error = _, _hasError = true;
      } finally {
        __callDispose(_stack, _error, _hasError);
      }
    }
    log2("fn before");
    fn();
    log2("fn after");
    expect(history).toMatchInlineSnapshot(`
      Array [
        "fn before",
        "constructor",
        "fn return",
        "dispose",
        "fn after",
      ]
    `);
  });
});
//# sourceMappingURL=dispose-defer.spec.js.map