import {
  useDisposeWithUtils,
  useEventListener,
  useTimeout
} from "../chunk-UE2PB4HJ.js";
import "../chunk-HH5MZIMF.js";
import "../chunk-VNLRM2QZ.js";
import "../chunk-UYLJHAX3.js";
import "../chunk-YFNV56TG.js";
import "../chunk-YVLJVKPH.js";
import "../chunk-B47EOWH4.js";
import "../chunk-XH3UHC3W.js";
import "../chunk-NHKHMG5M.js";
import "../chunk-KUFV2R7W.js";
import "../chunk-5OVSRAPG.js";
import "../chunk-OGMPYNGB.js";
import "../chunk-WEBXXRYZ.js";
import {
  polyfillUsing
} from "../chunk-GPE2GR6Y.js";
import "../chunk-TSCDX4AS.js";
import "../chunk-D6B6MYVG.js";
import "../chunk-XWWQZH6C.js";
import "../chunk-Y7J6ADHV.js";
import "../chunk-OKUAPZFI.js";
import "../chunk-QS2OVW4B.js";
import "../chunk-7IUVQQ4S.js";
import "../chunk-MIZOLME5.js";
import "../chunk-UJR57SSR.js";
import "../chunk-YX6CL4KH.js";
import "../chunk-I45WP5PM.js";
import "../chunk-ZFRTRIT4.js";
import "../chunk-CFICINSP.js";
import "../chunk-3KKFLSLG.js";
import "../chunk-5Y3HYG6B.js";
import "../chunk-FPJHSFML.js";
import "../chunk-XSB2WAW2.js";
import "../chunk-NYCGHEIN.js";
import "../chunk-AS5LR4AI.js";
import "../chunk-2H4XRKWS.js";
import "../chunk-NSJKG6AJ.js";
import "../chunk-XHROZN2O.js";
import "../chunk-3SMFSMCY.js";
import "../chunk-X2DIUKLP.js";
import "../chunk-KCHV27UP.js";
import "../chunk-DUQ7DD4G.js";
import "../chunk-2HWPZ6ZE.js";
import "../chunk-DGP32WEQ.js";
import "../chunk-NS46DWU4.js";
import "../chunk-73CVRDI7.js";
import "../chunk-FL5CT6MC.js";
import "../chunk-FQCORE5F.js";
import "../chunk-L324TYGN.js";
import "../chunk-MRFHKDNG.js";
import "../chunk-HLRQ5H3N.js";
import "../chunk-DXSTF7NX.js";
import "../chunk-AY5LGXTC.js";
import "../chunk-OQSDTQAF.js";
import "../chunk-SOTGICOC.js";
import "../chunk-DUON5DN5.js";
import "../chunk-GY34N3KU.js";
import "../chunk-IZT6OHMS.js";
import "../chunk-JJD2XTS2.js";
import "../chunk-TYWNSO7K.js";
import "../chunk-ZMFW3O35.js";
import "../chunk-5BQNKE5C.js";
import "../chunk-7NSVDPHN.js";
import "../chunk-WG6ZJDFQ.js";
import "../chunk-VWBTJP5F.js";
import {
  __callDispose,
  __using
} from "../chunk-LRAR7IPU.js";

// src/common/dispose-utils.spec.ts
import { vi as jest } from "vitest";
describe("useTimeout", () => {
  it("should call the provided function after the specified timeout", () => {
    jest.useFakeTimers();
    const mockFn = jest.fn();
    const timeout = 1e3;
    useTimeout(mockFn, timeout);
    expect(mockFn).not.toBeCalled();
    jest.advanceTimersByTime(timeout);
    expect(mockFn).toBeCalled();
  });
  it("should cancel the timeout when the disposer function is called", () => {
    jest.useFakeTimers();
    const mockFn = jest.fn();
    const timeout = 1e3;
    const disposer = useTimeout(mockFn, timeout);
    expect(mockFn).not.toBeCalled();
    disposer();
    jest.advanceTimersByTime(timeout);
    expect(mockFn).not.toBeCalled();
  });
  it('should add event listener using "on" method if available', () => {
    const emitter = {
      on: jest.fn(),
      off: jest.fn()
    };
    const eventName = "click";
    const fn = jest.fn();
    const args = [1, 2, 3];
    const disposer = useEventListener(emitter, eventName, fn, ...args);
    expect(emitter.on).toBeCalledWith(eventName, fn, ...args);
    expect(emitter.off).not.toBeCalled();
    disposer();
    expect(emitter.off).toBeCalledWith(eventName, fn, ...args);
  });
  it('should add event listener using "on" method if available using using', () => {
    const emitter = {
      on: jest.fn(),
      off: jest.fn()
    };
    const eventName = "click";
    const fn = jest.fn();
    const args = [1, 2, 3];
    polyfillUsing();
    function helper() {
      var _stack = [];
      try {
        const _ = __using(_stack, useEventListener(emitter, eventName, fn, ...args));
        expect(emitter.on).toBeCalledWith(eventName, fn, ...args);
        expect(emitter.off).not.toBeCalled();
      } catch (_2) {
        var _error = _2, _hasError = true;
      } finally {
        __callDispose(_stack, _error, _hasError);
      }
    }
    helper();
    expect(emitter.off).toBeCalledWith(eventName, fn, ...args);
  });
  it('should add event listener using "addEventListener" method if "on" method is not available', () => {
    const emitter = {
      addEventListener: jest.fn(),
      removeEventListener: jest.fn()
    };
    const eventName = "click";
    const fn = jest.fn();
    const args = [1, 2, 3];
    const disposer = useEventListener(emitter, eventName, fn, ...args);
    expect(emitter.addEventListener).toBeCalledWith(eventName, fn, ...args);
    expect(emitter.removeEventListener).not.toBeCalled();
    disposer();
    expect(emitter.removeEventListener).toBeCalledWith(eventName, fn, ...args);
  });
  it("should return an empty disposer function if emitter is null", () => {
    const emitter = null;
    const eventName = "click";
    const fn = jest.fn();
    const args = [1, 2, 3];
    const disposer = useEventListener(emitter, eventName, fn, ...args);
    expect(disposer).toEqual(expect.any(Function));
    disposer();
  });
  it("should add timeout disposer to the dispose object", () => {
    jest.useFakeTimers();
    const mockFn = jest.fn();
    const timeout = 1e3;
    const dispose = useDisposeWithUtils();
    dispose.timeout(mockFn, timeout);
    expect(mockFn).not.toBeCalled();
    jest.advanceTimersByTime(timeout);
    expect(mockFn).toBeCalled();
  });
  it("should add interval disposer to the dispose object", () => {
    jest.useFakeTimers();
    const mockFn = jest.fn();
    const interval = 1e3;
    const dispose = useDisposeWithUtils();
    dispose.interval(mockFn, interval);
    expect(mockFn).not.toBeCalled();
    jest.advanceTimersByTime(interval);
    expect(mockFn).toBeCalled();
  });
  it('should add event listener disposer to the dispose object using "on" method', async () => {
    const emitter = {
      on: jest.fn(),
      off: jest.fn()
    };
    const eventName = "click";
    const fn = jest.fn();
    const args = [1, 2, 3];
    const dispose = useDisposeWithUtils();
    dispose.on(emitter, eventName, fn, ...args);
    expect(emitter.on).toBeCalledWith(eventName, fn, ...args);
    expect(emitter.off).not.toBeCalled();
    await dispose.dispose();
    expect(emitter.off).toBeCalledWith(eventName, fn, ...args);
  });
  it('should add event listener disposer to the dispose object using "addEventListener" method', async () => {
    const emitter = {
      addEventListener: jest.fn(),
      removeEventListener: jest.fn()
    };
    const eventName = "click";
    const fn = jest.fn();
    const args = [1, 2, 3];
    const dispose = useDisposeWithUtils();
    dispose.on(emitter, eventName, fn, ...args);
    expect(emitter.addEventListener).toBeCalledWith(eventName, fn, ...args);
    expect(emitter.removeEventListener).not.toBeCalled();
    await dispose.dispose();
    expect(emitter.removeEventListener).toBeCalledWith(eventName, fn, ...args);
  });
  it("should return an empty disposer function if emitter is null 2", () => {
    const emitter = null;
    const eventName = "click";
    const fn = jest.fn();
    const args = [1, 2, 3];
    const dispose = useDisposeWithUtils();
    const disposer = dispose.on(emitter, eventName, fn, ...args);
    expect(disposer).toEqual(expect.any(Function));
    disposer();
  });
});
//# sourceMappingURL=dispose-utils.spec.js.map