import {
  decodeJson,
  encodeJson
} from "../../chunk-YUEJKLRT.js";
import "../../chunk-MO24G7VK.js";
import "../../chunk-QQSABUQG.js";
import "../../chunk-RNL46FQ3.js";
import "../../chunk-MWUFUBY5.js";
import "../../chunk-GKKLBSFA.js";
import "../../chunk-PDBCA7WB.js";
import {
  useRPC,
  useRPCHub
} from "../../chunk-VNLRM2QZ.js";
import {
  createLocalChannelPair
} from "../../chunk-B47EOWH4.js";
import "../../chunk-XH3UHC3W.js";
import "../../chunk-OGMPYNGB.js";
import "../../chunk-WEBXXRYZ.js";
import "../../chunk-GPE2GR6Y.js";
import "../../chunk-TSCDX4AS.js";
import "../../chunk-D6B6MYVG.js";
import "../../chunk-XWWQZH6C.js";
import "../../chunk-Y7J6ADHV.js";
import "../../chunk-OKUAPZFI.js";
import "../../chunk-QS2OVW4B.js";
import "../../chunk-7IUVQQ4S.js";
import "../../chunk-MIZOLME5.js";
import "../../chunk-UJR57SSR.js";
import "../../chunk-YX6CL4KH.js";
import "../../chunk-I45WP5PM.js";
import "../../chunk-ZFRTRIT4.js";
import "../../chunk-CFICINSP.js";
import "../../chunk-3KKFLSLG.js";
import "../../chunk-5Y3HYG6B.js";
import "../../chunk-FPJHSFML.js";
import "../../chunk-XSB2WAW2.js";
import "../../chunk-NYCGHEIN.js";
import "../../chunk-AS5LR4AI.js";
import {
  useStringHashPool
} from "../../chunk-2H4XRKWS.js";
import "../../chunk-NSJKG6AJ.js";
import "../../chunk-XHROZN2O.js";
import "../../chunk-3SMFSMCY.js";
import "../../chunk-X2DIUKLP.js";
import "../../chunk-KCHV27UP.js";
import "../../chunk-DUQ7DD4G.js";
import "../../chunk-2HWPZ6ZE.js";
import "../../chunk-DGP32WEQ.js";
import "../../chunk-NS46DWU4.js";
import "../../chunk-73CVRDI7.js";
import "../../chunk-FL5CT6MC.js";
import "../../chunk-FQCORE5F.js";
import {
  sleep
} from "../../chunk-L324TYGN.js";
import "../../chunk-MRFHKDNG.js";
import "../../chunk-HLRQ5H3N.js";
import "../../chunk-DXSTF7NX.js";
import "../../chunk-AY5LGXTC.js";
import "../../chunk-OQSDTQAF.js";
import "../../chunk-SOTGICOC.js";
import "../../chunk-DUON5DN5.js";
import "../../chunk-GY34N3KU.js";
import "../../chunk-IZT6OHMS.js";
import "../../chunk-JJD2XTS2.js";
import "../../chunk-TYWNSO7K.js";
import "../../chunk-ZMFW3O35.js";
import {
  cloneObject
} from "../../chunk-5BQNKE5C.js";
import "../../chunk-7NSVDPHN.js";
import "../../chunk-WG6ZJDFQ.js";
import "../../chunk-VWBTJP5F.js";
import "../../chunk-LRAR7IPU.js";

// src/common/msg/rpc.spec.ts
var bobCount = 0;
var Bob = {
  hi(name) {
    return `Hi ${name}, I am Bob`;
  },
  bump() {
    bobCount += 1;
  },
  getCount() {
    return bobCount;
  }
};
var Alice = {
  hello(name) {
    return `Hello ${name}, my name is Alice`;
  }
};
describe("rpc async", () => {
  beforeEach(() => {
    bobCount = 0;
  });
  it("basic", async () => {
    const log = [];
    const [c1, c2] = createLocalChannelPair();
    const serialize = (data) => {
      log.push(cloneObject(data));
      return encodeJson(data);
    };
    const deserialize = (data) => decodeJson(data);
    const bob = useRPC(Bob, {
      post: (data) => c1.postMessage(data),
      on: (data) => c1.on("message", (e) => data(e.data)),
      serialize,
      deserialize,
      stringHashPool: useStringHashPool()
    });
    const alice = useRPC(Alice, {
      // mark bob's `bump` as an event without response
      eventNames: ["bump"],
      post: (data) => c2.postMessage(data),
      on: (data) => c2.on("message", (e) => data(e.data)),
      serialize,
      deserialize,
      stringHashPool: useStringHashPool()
    });
    expect(await bob.hello("Bob")).toEqual("Hello Bob, my name is Alice");
    expect(await alice.hi("Alice")).toEqual("Hi Alice, I am Bob");
    expect(void alice.bump()).toBeUndefined();
    expect(Bob.getCount()).toBe(0);
    await new Promise((resolve) => setTimeout(resolve, 100));
    expect(Bob.getCount()).toBe(1);
    c1.close();
    c2.close();
    expect(log).toMatchInlineSnapshot(`
      Array [
        Array [
          1,
          1,
          1335831723,
          "Bob",
        ],
        Array [
          3,
          1,
          "Hello Bob, my name is Alice",
        ],
        Array [
          1,
          2,
          1748694682,
          "Alice",
        ],
        Array [
          3,
          2,
          "Hi Alice, I am Bob",
        ],
        Array [
          2,
          1648103349,
        ],
      ]
    `);
  });
  it("hub", async () => {
    const [c1, c2] = createLocalChannelPair();
    const serialize = (data) => encodeJson(data);
    const deserialize = (data) => decodeJson(data);
    const bobHub = useRPCHub({
      post: (data) => c1.postMessage(data),
      on: (data) => c1.on("message", (e) => data(e.data)),
      serialize,
      deserialize,
      stringHashPool: useStringHashPool()
    });
    const bob = bobHub(Bob);
    const alice = useRPC(Alice, {
      // mark bob's `bump` as an event without response
      eventNames: ["bump"],
      post: (data) => c2.postMessage(data),
      on: (data) => c2.on("message", (e) => data(e.data)),
      serialize,
      deserialize,
      stringHashPool: useStringHashPool()
    });
    expect(await bob.hello("Bob")).toEqual("Hello Bob, my name is Alice");
    expect(await alice.hi("Alice")).toEqual("Hi Alice, I am Bob");
    expect(void alice.bump()).toBeUndefined();
    expect(Bob.getCount()).toBe(0);
    await new Promise((resolve) => setTimeout(resolve, 100));
    expect(Bob.getCount()).toBe(1);
    c1.close();
    c2.close();
  });
  it("timeout async", async (done) => {
    const [f1, f2] = createLocalChannelPair();
    const rpc1 = useRPC({
      async echo(v, s = 5) {
        await sleep(s);
        return `${v}_1`;
      }
    }, {
      post: (data) => {
        f1.postMessage(data);
      },
      on: (data) => f1.on("message", (msg) => {
        void data(msg.data);
      }),
      timeout: 10
    });
    const rpc2 = useRPC({
      async echo(v, s = 5) {
        await sleep(s);
        return `${v}_2`;
      }
    }, {
      post: (data) => {
        f2.postMessage(data);
      },
      on: (data) => f2.on("message", (msg) => {
        void data(msg.data);
      }),
      timeout: 10
    });
    const r = await rpc1.echo("abc");
    expect(r).toMatchInlineSnapshot(`"abc_2"`);
    try {
      const r2 = await rpc1.echo("abc", 50);
      expect(false).toBe(true);
    } catch (err) {
      expect(err).toMatchInlineSnapshot(`[Error: rpc timeout on calling "echo"]`);
    }
  });
  it("async", async (done) => {
    function echo(n) {
      return n;
    }
    async function echoAsync(n) {
      return n;
    }
    expect(await echo(1)).toBe(1);
    expect(await echoAsync(2)).toBe(2);
  });
});
//# sourceMappingURL=rpc.spec.js.map